% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lnVR_wrappers.R
\docType{data}
\name{.lnVR_args}
\alias{.lnVR_args}
\title{Required columns for computing lnVR}
\format{
An object of class \code{list} of length 2.
}
\usage{
.lnVR_args
}
\description{
'inter' use the same arguments than 'main',
}
\keyword{internal}
