% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/time_lnVR.R
\name{.time_interaction_lnVR}
\alias{.time_interaction_lnVR}
\title{Log of Variability Ratio: Interaction Between Experimental Treatment and Time}
\usage{
.time_interaction_lnVR(
  t0_Ctrl_sd,
  t1_Ctrl_sd,
  Ctrl_n,
  Ctrl_cor,
  t0_Exp_sd,
  t1_Exp_sd,
  Exp_n,
  Exp_cor
)
}
\arguments{
\item{t0_Ctrl_sd}{Standard deviation from the control group at time 0}

\item{t1_Ctrl_sd}{Standard deviation from the control group at time 1}

\item{Ctrl_n}{Sample size of the control group}

\item{Ctrl_cor}{Correlation between the means of the control group at t0 and t1}

\item{t0_Exp_sd}{Standard deviation from the experimental group at time 0}

\item{t1_Exp_sd}{Standard deviation from the experimental group at time 1}

\item{Exp_n}{Sample size of the experimental group}

\item{Exp_cor}{Correlation between the means of the experimental group at t0 and t1}
}
\description{
Log of Variability Ratio: Interaction Between Experimental Treatment and Time
}
\keyword{internal}
